==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/itextvector.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//*********************************************************************
//
//  Class for displaying vector (3D) text in VTK
//
//*********************************************************************


#ifndef ITEXTVECTOR_H
#define ITEXTVECTOR_H


#include "itext.h"

class iTransform;

class vtkActor2D;
class vtkPolyDataMapper2D;
class vtkTransformPolyDataFilter;
class vtkVectorText;


class iTextVector: public iText 
{
	
public:
	
	static iTextVector* New(const iRenderTool *rv){ return new iTextVector(rv); }
	
	virtual int RenderOverlay(vtkViewport *v);
	virtual int RenderOpaqueGeometry(vtkViewport *v);
	
	virtual void ReleaseGraphicsResources(vtkWindow *w);

	virtual void GetSize(vtkViewport *v, float s[2]);

protected:
	
	iTextVector(const iRenderTool *rv);
	virtual ~iTextVector();
	
	vtkVectorText *mSource;
	iTransform *mTransform;
	vtkTransformPolyDataFilter *mFilter;
	vtkPolyDataMapper2D *mMapper;
	vtkActor2D *mActor, *mActorShadow;
};

#endif // ITEXTVECTOR_H

==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/core/itextvector.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//*********************************************************************
//
//  Class for displaying vector (3D) text in VTK
//
//*********************************************************************


#ifndef ITEXTVECTOR_H
#define ITEXTVECTOR_H


#include "itext.h"

class iTransform;

class vtkActor2D;
class vtkPolyDataMapper2D;
class vtkTransformPolyDataFilter;
class vtkVectorText;


class iTextVector: public iText 
{
	
public:
	
	static iTextVector* New(iRenderTool *rv);
	
	virtual int RenderOverlay(vtkViewport *v);
	virtual int RenderOpaqueGeometry(vtkViewport *v);
	
	virtual void ReleaseGraphicsResources(vtkWindow *w);

	virtual void GetSize(vtkViewport *v, float s[2]);

protected:

	virtual ~iTextVector();

private:
	
	iTextVector(iRenderTool *rv);
	
	vtkVectorText *mSource;
	iTransform *mTransform;
	vtkTransformPolyDataFilter *mFilter;
	vtkPolyDataMapper2D *mMapper;
	vtkActor2D *mActor, *mActorShadow;
};

#endif // ITEXTVECTOR_H
